Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(298)

Unified Diff: chrome/browser/about_flags.cc

Issue 2870893003: chromeos: Adds --mus flag (Closed)
Patch Set: feedback Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/flag_descriptions.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/about_flags.cc
diff --git a/chrome/browser/about_flags.cc b/chrome/browser/about_flags.cc
index 08f08585f7a4b8c304c8893358bb1dd463941383..e4ddf8c370894b526116cf3fbd8283258e2c861c 100644
--- a/chrome/browser/about_flags.cc
+++ b/chrome/browser/about_flags.cc
@@ -456,6 +456,12 @@ const FeatureEntry::Choice kDataSaverPromptChoices[] = {
chromeos::switches::kDataSaverPromptDemoMode},
};
+const FeatureEntry::Choice kUseMusChoices[] = {
+ {flags_ui::kGenericExperimentChoiceDefault, "", ""},
+ {flag_descriptions::kEnableMusDescription, switches::kMus, ""},
+ {flag_descriptions::kEnableMashDescription, switches::kMash, ""},
+};
+
const FeatureEntry::Choice kUiShowCompositedLayerBordersChoices[] = {
{flags_ui::kGenericExperimentChoiceDefault, "", ""},
{flag_descriptions::kUiShowCompositedLayerBordersRenderPass,
@@ -1276,9 +1282,9 @@ const FeatureEntry kFeatureEntries[] = {
FEATURE_VALUE_TYPE(features::kRunAllFlashInAllowMode)},
#endif // ENABLE_PLUGINS
#if defined(OS_CHROMEOS)
- {"mash", flag_descriptions::kUseMashName,
- flag_descriptions::kUseMashDescription, kOsCrOS,
- SINGLE_VALUE_TYPE(switches::kMash)},
+ {"mus", flag_descriptions::kUseMusName,
+ flag_descriptions::kUseMusDescription, kOsCrOS,
+ MULTI_VALUE_TYPE(kUseMusChoices)},
{"allow-touchpad-three-finger-click",
flag_descriptions::kAllowTouchpadThreeFingerClickName,
flag_descriptions::kAllowTouchpadThreeFingerClickDescription, kOsCrOS,
@@ -2959,8 +2965,8 @@ bool SkipConditionalFeatureEntry(const FeatureEntry& entry) {
#endif // OS_ANDROID
#if defined(OS_CHROMEOS)
- // Don't expose --mash outside of Canary or developer builds.
- if (!strcmp("mash", entry.internal_name) &&
+ // Don't expose --mash/--mus outside of Canary or developer builds.
+ if (!strcmp("mus", entry.internal_name) &&
channel != version_info::Channel::DEV &&
channel != version_info::Channel::UNKNOWN) {
return true;
« no previous file with comments | « no previous file | chrome/browser/flag_descriptions.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698